package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.GoodsOrderCursor;

/**
 * 商品订单临时Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IGoodsOrderCursorService 
{
    /**
     * 查询商品订单临时
     * 
     * @param id 商品订单临时主键
     * @return 商品订单临时
     */
    public GoodsOrderCursor selectGoodsOrderCursorById(Long id);

    /**
     * 查询商品订单临时列表
     * 
     * @param goodsOrderCursor 商品订单临时
     * @return 商品订单临时集合
     */
    public List<GoodsOrderCursor> selectGoodsOrderCursorList(GoodsOrderCursor goodsOrderCursor);

    /**
     * 新增商品订单临时
     * 
     * @param goodsOrderCursor 商品订单临时
     * @return 结果
     */
    public int insertGoodsOrderCursor(GoodsOrderCursor goodsOrderCursor);

    /**
     * 修改商品订单临时
     * 
     * @param goodsOrderCursor 商品订单临时
     * @return 结果
     */
    public int updateGoodsOrderCursor(GoodsOrderCursor goodsOrderCursor);

    /**
     * 批量删除商品订单临时
     * 
     * @param ids 需要删除的商品订单临时主键集合
     * @return 结果
     */
    public int deleteGoodsOrderCursorByIds(Long[] ids);

    /**
     * 删除商品订单临时信息
     * 
     * @param id 商品订单临时主键
     * @return 结果
     */
    public int deleteGoodsOrderCursorById(Long id);
}
