package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.GoodsOrderCursor;
import com.ruoyi.system.service.IGoodsOrderCursorService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商品订单临时Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/GoodsOrderCursor")
public class GoodsOrderCursorController extends BaseController
{
    @Autowired
    private IGoodsOrderCursorService goodsOrderCursorService;

    /**
     * 查询商品订单临时列表
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsOrderCursor:list')")
    @GetMapping("/list")
    public TableDataInfo list(GoodsOrderCursor goodsOrderCursor)
    {
        startPage();
        List<GoodsOrderCursor> list = goodsOrderCursorService.selectGoodsOrderCursorList(goodsOrderCursor);
        return getDataTable(list);
    }

    /**
     * 导出商品订单临时列表
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsOrderCursor:export')")
    @Log(title = "商品订单临时", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GoodsOrderCursor goodsOrderCursor)
    {
        List<GoodsOrderCursor> list = goodsOrderCursorService.selectGoodsOrderCursorList(goodsOrderCursor);
        ExcelUtil<GoodsOrderCursor> util = new ExcelUtil<GoodsOrderCursor>(GoodsOrderCursor.class);
        util.exportExcel(response, list, "商品订单临时数据");
    }

    /**
     * 获取商品订单临时详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsOrderCursor:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(goodsOrderCursorService.selectGoodsOrderCursorById(id));
    }

    /**
     * 新增商品订单临时
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsOrderCursor:add')")
    @Log(title = "商品订单临时", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GoodsOrderCursor goodsOrderCursor)
    {
        return toAjax(goodsOrderCursorService.insertGoodsOrderCursor(goodsOrderCursor));
    }

    /**
     * 修改商品订单临时
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsOrderCursor:edit')")
    @Log(title = "商品订单临时", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GoodsOrderCursor goodsOrderCursor)
    {
        return toAjax(goodsOrderCursorService.updateGoodsOrderCursor(goodsOrderCursor));
    }

    /**
     * 删除商品订单临时
     */
    @PreAuthorize("@ss.hasPermi('system:GoodsOrderCursor:remove')")
    @Log(title = "商品订单临时", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(goodsOrderCursorService.deleteGoodsOrderCursorByIds(ids));
    }
}
